@@ -20,11 +20,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0160
+Version 0.0161
 
 =cut
 
-our $VERSION = '0.0160';
+our $VERSION = '0.0161';
 
 =head1 SYNOPSIS
 
@@ -913,7 +913,12 @@ sub _replace_within_elts {
 			# replace attribute instead of embedded text (e.g. for <input>)
             foreach my $replace_attr (_expand_elt_attributes($elt, $zref->{rep_att})) {
                 if (exists $param->{op} && $param->{op} eq 'append') {
-                    my $original_attribute = $zref->{rep_att_orig}->{$replace_attr};
+                    my $original_attribute = '';
+
+                    if (exists $zref->{rep_att_orig}->{$replace_attr}) {
+                        $original_attribute = $zref->{rep_att_orig}->{$replace_attr};
+                    }
+
                     if (exists $param->{joiner}) {
                         if ($rep_str) {
                             $elt->set_att($replace_attr, $original_attribute . $param->{joiner} . $rep_str);
